pub struct LandingPageMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on landingPage resources.
It is not used directly, but through the Dfareporting hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_dfareporting2d8 as dfareporting2d8;
use dfareporting2d8::{Dfareporting, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Dfareporting::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `insert(...)`, `list(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.landing_pages();Implementations
Sourceimpl<'a, C> LandingPageMethods<'a, C>
impl<'a, C> LandingPageMethods<'a, C>
Sourcepub fn delete(
&self,
profile_id: i64,
campaign_id: i64,
id: i64,
) -> LandingPageDeleteCall<'a, C>
pub fn delete( &self, profile_id: i64, campaign_id: i64, id: i64, ) -> LandingPageDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes an existing campaign landing page.
Arguments
profileId- User profile ID associated with this request.campaignId- Landing page campaign ID.id- Landing page ID.
Sourcepub fn get(
&self,
profile_id: i64,
campaign_id: i64,
id: i64,
) -> LandingPageGetCall<'a, C>
pub fn get( &self, profile_id: i64, campaign_id: i64, id: i64, ) -> LandingPageGetCall<'a, C>
Create a builder to help you perform the following task:
Gets one campaign landing page by ID.
Arguments
profileId- User profile ID associated with this request.campaignId- Landing page campaign ID.id- Landing page ID.
Sourcepub fn insert(
&self,
request: LandingPage,
profile_id: i64,
campaign_id: i64,
) -> LandingPageInsertCall<'a, C>
pub fn insert( &self, request: LandingPage, profile_id: i64, campaign_id: i64, ) -> LandingPageInsertCall<'a, C>
Create a builder to help you perform the following task:
Inserts a new landing page for the specified campaign.
Arguments
request- No description provided.profileId- User profile ID associated with this request.campaignId- Landing page campaign ID.
Sourcepub fn list(
&self,
profile_id: i64,
campaign_id: i64,
) -> LandingPageListCall<'a, C>
pub fn list( &self, profile_id: i64, campaign_id: i64, ) -> LandingPageListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves the list of landing pages for the specified campaign.
Arguments
profileId- User profile ID associated with this request.campaignId- Landing page campaign ID.
Sourcepub fn patch(
&self,
request: LandingPage,
profile_id: i64,
campaign_id: i64,
id: i64,
) -> LandingPagePatchCall<'a, C>
pub fn patch( &self, request: LandingPage, profile_id: i64, campaign_id: i64, id: i64, ) -> LandingPagePatchCall<'a, C>
Create a builder to help you perform the following task:
Updates an existing campaign landing page. This method supports patch semantics.
Arguments
request- No description provided.profileId- User profile ID associated with this request.campaignId- Landing page campaign ID.id- Landing page ID.
Sourcepub fn update(
&self,
request: LandingPage,
profile_id: i64,
campaign_id: i64,
) -> LandingPageUpdateCall<'a, C>
pub fn update( &self, request: LandingPage, profile_id: i64, campaign_id: i64, ) -> LandingPageUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates an existing campaign landing page.
Arguments
request- No description provided.profileId- User profile ID associated with this request.campaignId- Landing page campaign ID.