Struct google_dfareporting2d8::api::OperatingSystemMethods[][src]

pub struct OperatingSystemMethods<'a> { /* fields omitted */ }

A builder providing access to all methods supported on operatingSystem resources. It is not used directly, but through the Dfareporting hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_dfareporting2d8 as dfareporting2d8;
 
use std::default::Default;
use oauth2;
use dfareporting2d8::Dfareporting;
 
let secret: oauth2::ApplicationSecret = Default::default();
let auth = yup_oauth2::InstalledFlowAuthenticator::builder(
        secret,
        yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
    ).build().await.unwrap();
let mut hub = Dfareporting::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)` and `list(...)`
// to build up your call.
let rb = hub.operating_systems();

Implementations

impl<'a> OperatingSystemMethods<'a>[src]

pub fn get(&self, profile_id: &str, dart_id: &str) -> OperatingSystemGetCall<'a>[src]

Create a builder to help you perform the following task:

Gets one operating system by DART ID.

Arguments

  • profileId - User profile ID associated with this request.
  • dartId - Operating system DART ID.

pub fn list(&self, profile_id: &str) -> OperatingSystemListCall<'a>[src]

Create a builder to help you perform the following task:

Retrieves a list of operating systems.

Arguments

  • profileId - User profile ID associated with this request.